"use strict";

exports.__esModule = true;
exports.Default = exports.Case = exports.default = void 0;

var _react = require("react");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Switch component for React
 *
 * Switch parameters:
 * condition {String} is condition for choice children component
 *
 * Case parameters:
 * value {String} is anchor for Switch
 * */
class Switch extends _react.Component {
  getChildren() {
    let cases = [],
        defaults = [];

    _react.Children.forEach(this.props.children, item => {
      switch (item.type.componentName) {
        case 'case':
          if (typeof this.props.condition === 'function') {
            if (this.props.condition(item.props.value)) {
              cases.push(item);
            }
          } else if (this.props.condition === item.props.value) {
            cases.push(item);
          }

          break;

        case 'default':
          defaults.push(item);
          break;
      }
    });

    if (cases.length > 0) {
      return cases;
    }

    return defaults;
  }

  render() {
    const children = this.getChildren();
    return children.length === 0 ? null : children;
  }

}

class Case extends _react.Component {
  render() {
    return this.props.children;
  }

}

exports.Case = Case;

_defineProperty(Case, "componentName", 'case');

class Default extends _react.Component {
  render() {
    return this.props.children;
  }

}

exports.Default = Default;

_defineProperty(Default, "componentName", 'default');

var _default = Switch;
exports.default = _default;