function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { Component, Children } from 'react';
/**
 * Switch component for React
 *
 * Switch parameters:
 * condition {String} is condition for choice children component
 *
 * Case parameters:
 * value {String} is anchor for Switch
 * */

class Switch extends Component {
  getChildren() {
    let cases = [],
        defaults = [];
    Children.forEach(this.props.children, item => {
      switch (item.type.componentName) {
        case 'case':
          if (typeof this.props.condition === 'function') {
            if (this.props.condition(item.props.value)) {
              cases.push(item);
            }
          } else if (this.props.condition === item.props.value) {
            cases.push(item);
          }

          break;

        case 'default':
          defaults.push(item);
          break;
      }
    });

    if (cases.length > 0) {
      return cases;
    }

    return defaults;
  }

  render() {
    const children = this.getChildren();
    return children.length === 0 ? null : children;
  }

}

class Case extends Component {
  render() {
    return this.props.children;
  }

}

_defineProperty(Case, "componentName", 'case');

class Default extends Component {
  render() {
    return this.props.children;
  }

}

_defineProperty(Default, "componentName", 'default');

export default Switch;
export { Case };
export { Default };